@@ -256,7 +256,11 @@ class ConstructHubProps:
 @jsii.data_type(
     jsii_type="construct-hub.Domain",
     jsii_struct_bases=[],
-    name_mapping={"cert": "cert", "zone": "zone"},
+    name_mapping={
+        "cert": "cert",
+        "zone": "zone",
+        "monitor_certificate_expiration": "monitorCertificateExpiration",
+    },
 )
 class Domain:
     def __init__(
@@ -264,11 +268,13 @@ class Domain:
         *,
         cert: aws_cdk.aws_certificatemanager.ICertificate,
         zone: aws_cdk.aws_route53.IHostedZone,
+        monitor_certificate_expiration: typing.Optional[builtins.bool] = None,
     ) -> None:
         '''(experimental) Domain configuration for the website.
 
         :param cert: (experimental) The certificate to use for serving the Construct Hub over a custom domain. Default: - a DNS-Validated certificate will be provisioned using the provided ``hostedZone``.
         :param zone: (experimental) The root domain name where this instance of Construct Hub will be served.
+        :param monitor_certificate_expiration: (experimental) Whether the certificate should be monitored for expiration, meaning high severity alarms will be raised if it is due to expire in less than 45 days. Default: true
 
         :stability: experimental
         '''
@@ -276,6 +282,8 @@ class Domain:
             "cert": cert,
             "zone": zone,
         }
+        if monitor_certificate_expiration is not None:
+            self._values["monitor_certificate_expiration"] = monitor_certificate_expiration
 
     @builtins.property
     def cert(self) -> aws_cdk.aws_certificatemanager.ICertificate:
@@ -302,6 +310,17 @@ class Domain:
         assert result is not None, "Required property 'zone' is missing"
         return typing.cast(aws_cdk.aws_route53.IHostedZone, result)
 
+    @builtins.property
+    def monitor_certificate_expiration(self) -> typing.Optional[builtins.bool]:
+        '''(experimental) Whether the certificate should be monitored for expiration, meaning high severity alarms will be raised if it is due to expire in less than 45 days.
+
+        :default: true
+
+        :stability: experimental
+        '''
+        result = self._values.get("monitor_certificate_expiration")
+        return typing.cast(typing.Optional[builtins.bool], result)
+
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
